@@ -135,6 +135,7 @@ class TestProfilerOptions(unittest.TestCase):
         options.structured_options.datetime.is_enabled = False
         options.structured_options.order.is_enabled = False
         options.structured_options.category.is_enabled = False
+        options.structured_options.chi2_homogeneity.is_enabled = False
         options.structured_options.data_labeler.is_enabled = False
         profile = Profiler(self.data, options=options)
         for col_profiler in profile.profile:
@@ -172,12 +173,14 @@ class TestProfilerOptions(unittest.TestCase):
             "min.is_enabled": False,
             "max.is_enabled": False,
             "mode.is_enabled": False,
+            "median.is_enabled": False,
             "sum.is_enabled": False,
             "variance.is_enabled": False,
             "skewness.is_enabled": False,
             "kurtosis.is_enabled": False,
             "num_zeros.is_enabled": False,
             "num_negatives.is_enabled": False,
+            "median_abs_deviation.is_enabled": False
         }
         options.set(statistical_options)
 
@@ -187,6 +190,7 @@ class TestProfilerOptions(unittest.TestCase):
         int_options = options.structured_options.int.properties
         for option in ["histogram_and_quantiles", "min", "max", "sum",
                        "mode", "variance", "skewness", "kurtosis",
+                       "median_abs_deviation",
                        "num_zeros", "num_negatives"]:
             self.assertFalse(text_options[option].is_enabled)
             self.assertFalse(float_options[option].is_enabled)
@@ -211,7 +215,10 @@ class TestProfilerOptions(unittest.TestCase):
                 self.assertIsNone(profile_column["statistics"]["quantiles"][0])
                 self.assertTrue(profile_column["statistics"]["skewness"] is np.nan)
                 self.assertTrue(profile_column["statistics"]["kurtosis"] is np.nan)
+                self.assertTrue(
+                    profile_column["statistics"]["median_abs_deviation"] is np.nan)
                 self.assertTrue(np.isnan(profile_column["statistics"]["mode"]))
+                self.assertTrue(np.isnan(profile_column["statistics"]["median"]))
 
     def test_validate(self, *mocks):
         options = ProfilerOptions()
@@ -237,10 +244,12 @@ class TestProfilerOptions(unittest.TestCase):
             "min.is_enabled": False,
             "max.is_enabled": False,
             "mode.is_enabled": False,
+            "median.is_enabled": False,
             "sum.is_enabled": False,
             "variance.is_enabled": True,
             "skewness.is_enabled": False,
-            "kurtosis.is_enabled": False
+            "kurtosis.is_enabled": False,
+            "median_abs_deviation.is_enabled": False
         }
         # Asserts error since sum must be toggled on if variance is
         expected_error = (
